Translate Toolkit 1.6.0 — Translate Toolkit 3.1.0 documentation

# Translate Toolkit 1.6.0

Released on 3 March 2010

## PO files now always have headers

Generated PO files now always contain headers. This will mainly affect the output of pofilter and pogrep. This should allow better interoperability with gettext tools, and allowed for some improvement in the code. You should still be able to use headerless files in msgmerge, although it is recommended that PO files are consistently handled with headers wherever possible.